#

##

##

##

    	databases

    		theme

    			reels, scenes, and moves

    		agenda

    			 escrow
    			 account balances

    		vernacular

    			squashes

    		collection_1 [{
    			#
    			#	These are sequential per squeeze
    			#
    			"date": 1,

    			#
    			#	These are unique as they don't need signatures
    			#
    			"structural": "yes",

    			"collection": 1,
    			"proposal": "proposal key",

    			"public key": "",
    			"private key signature": "",

    			"petition": {}
    		},{
    			"date": 2,

    			"structural": "yes",

    			"collection": 1,
    			"proposal": "friendship key",

    			"public key": "",
    			"private key signature": "",

    			"petition": {}
    		},{
    			"date": 3,

    			#
    			#	These are unique as they don't need signatures
    			#
    			"founder": "yes",

    			"collection": 1,
    			"proposal": "create rings",

    			"public key": "",
    			"private key signature": "",

    			"petition": {}
    		}]
    		collection_2 []
    		collection_3 []
    		collection_4 []

    	propose:
    		"create rings"

    		"proposal key"

    			{
    				"public key": "",
    				"private key signature": "",
    				"signatures": {
    					public_key : ""
    				}